#ifndef MOZC_DICTIONARY_POS_MATCHER_H_
#define MOZC_DICTIONARY_POS_MATCHER_H_
#include "base/base.h"
namespace mozc {
namespace {
class POSMatcher {
 public:
  // Functional "^(助詞|助動詞|動詞,非自立|名詞,非自立|形容詞,非自立|動詞,接尾|名詞,接尾|形容詞,接尾)"
  static uint16 GetFunctionalId() {
    return 42;
  }
  static bool IsFunctional(uint16 id) {
    return ((id >= 42 && id <= 603) || (id >= 1082 && id <= 1932) || (id >= 2018 && id <= 2043) || (id >= 2057 && id <= 2283) || (id >= 2553 && id <= 2665));
  }
  // Unknown "名詞,サ変接続"
  static uint16 GetUnknownId() {
    return 1933;
  }
  static bool IsUnknown(uint16 id) {
    return ((id >= 1933 && id <= 1936));
  }
  // FirstName "名詞,固有名詞,人名,名"
  static uint16 GetFirstNameId() {
    return 2008;
  }
  static bool IsFirstName(uint16 id) {
    return ((id == 2008));
  }
  // LastName "名詞,固有名詞,人名,姓"
  static uint16 GetLastNameId() {
    return 2009;
  }
  static bool IsLastName(uint16 id) {
    return ((id == 2009));
  }
  // Number "名詞,数,アラビア数字"
  static uint16 GetNumberId() {
    return 2046;
  }
  static bool IsNumber(uint16 id) {
    return ((id == 2046));
  }
  // KanjiNumber "名詞,数,漢数字"
  static uint16 GetKanjiNumberId() {
    return 2048;
  }
  static bool IsKanjiNumber(uint16 id) {
    return ((id >= 2048 && id <= 2055));
  }
  // WeakCompoundPrefix "^(接頭詞,名詞接続|接頭詞,丁寧連用形接続|フィラー)"
  static uint16 GetWeakCompoundPrefixId() {
    return 2;
  }
  static bool IsWeakCompoundPrefix(uint16 id) {
    return ((id >= 2 && id <= 11) || (id == 2668) || (id >= 2670 && id <= 2699));
  }
  // AcceptableParticleAtBeginOfSegment "^助詞,*,*,*,*,*,(が|で|と|に|にて|の|へ|より|も|と|から|は|や)$"
  static uint16 GetAcceptableParticleAtBeginOfSegmentId() {
    return 287;
  }
  static bool IsAcceptableParticleAtBeginOfSegment(uint16 id) {
    return ((id == 287) || (id == 290) || (id >= 299 && id <= 301) || (id >= 342 && id <= 343) || (id == 346) || (id == 348) || (id >= 362 && id <= 363) || (id == 376) || (id >= 380 && id <= 388) || (id == 391) || (id == 400) || (id == 402) || (id == 412) || (id == 431) || (id == 447) || (id == 453) || (id == 469));
  }
  // JapanesePunctuations "記号,(句点|読点)"
  static uint16 GetJapanesePunctuationsId() {
    return 2704;
  }
  static bool IsJapanesePunctuations(uint16 id) {
    return ((id == 2704) || (id == 2707));
  }
  // OpenBracket "記号,括弧開"
  static uint16 GetOpenBracketId() {
    return 2706;
  }
  static bool IsOpenBracket(uint16 id) {
    return ((id == 2706));
  }
  // CloseBracket "記号,括弧閉"
  static uint16 GetCloseBracketId() {
    return 2705;
  }
  static bool IsCloseBracket(uint16 id) {
    return ((id == 2705));
  }
  // Zipcode "特殊,郵便番号"
  static uint16 GetZipcodeId() {
    return 2721;
  }
  static bool IsZipcode(uint16 id) {
    return ((id == 2721));
  }
  // IsolatedWord "特殊,短縮よみ"
  static uint16 GetIsolatedWordId() {
    return 2722;
  }
  static bool IsIsolatedWord(uint16 id) {
    return ((id == 2722));
  }
  // SuggestOnlyWord "特殊,サジェストのみ"
  static uint16 GetSuggestOnlyWordId() {
    return 2723;
  }
  static bool IsSuggestOnlyWord(uint16 id) {
    return ((id == 2723));
  }
  // ContentWordWithConjugation "^(動詞,自立,*,*,五段|動詞,自立,*,*,一段|形容詞,自立)"
  static uint16 GetContentWordWithConjugationId() {
    return 719;
  }
  static bool IsContentWordWithConjugation(uint16 id) {
    return ((id >= 719 && id <= 1039) || (id >= 2284 && id <= 2552));
  }
  // SuffixWord "^(助詞|助動詞|動詞,非自立|動詞,接尾|形容詞,非自立|形容詞,接尾|動詞,自立,*,*,サ変・スル)"
  static uint16 GetSuffixWordId() {
    return 42;
  }
  static bool IsSuffixWord(uint16 id) {
    return ((id >= 42 && id <= 603) || (id >= 700 && id <= 712) || (id >= 1082 && id <= 1932) || (id >= 2197 && id <= 2283) || (id >= 2553 && id <= 2665));
  }
  // UniqueNoun "^名詞,固有名詞"
  static uint16 GetUniqueNounId() {
    return 2006;
  }
  static bool IsUniqueNoun(uint16 id) {
    return ((id >= 2006 && id <= 2015));
  }
  // GeneralNoun "^名詞,一般,*,*,*,*,*$"
  static uint16 GetGeneralNounId() {
    return 1938;
  }
  static bool IsGeneralNoun(uint16 id) {
    return ((id == 1938));
  }
 private:
  POSMatcher() {}
  ~POSMatcher() {}
};
}  // namespace
}  // mozc
#endif  // MOZC_DICTIONARY_POS_MATCHER_H_
